@@ -2,18 +2,22 @@ package QLayout;
 
 use strict;
 use vars qw($VERSION @ISA @EXPORT);
+use QGlobal qw(%Align $SingleLine $DontClip $ExpandTabs $ShowPrefix $WordBreak
+               $GrayText $DontPrint);
 
 require Exporter;
 require DynaLoader;
-require QGlobal;
 
 require QMenuBar;
 require QObject;
 
 @ISA = qw(Exporter DynaLoader QObject);
-@EXPORT = qw(%Direction);
+@EXPORT = qw(%Align $SingleLine $DontClip $ExpandTabs $ShowPrefix $WordBreak
+	     $GrayText $DontPrint
 
-$VERSION = '0.01';
+	     %Direction);
+
+$VERSION = '0.02';
 bootstrap QLayout $VERSION;
 
 
@@ -93,6 +97,10 @@ What you see is what you get.
 The C<%Direction> hash is exported on behalf of QBoxLayout. It contains
 all of the constants within QBoxLayout.
 
+The %Align $SingleLine $DontClip $ExpandTabs $ShowPrefix $WordBreak
+$GrayText $DontPrint constants are exported. See L<QPainter(3)>
+for info.
+
 =head1 AUTHOR
 
 Ashley Winters <jql@accessone.com>
