@@ -15,7 +15,7 @@ require QWMatrix;
 @ISA = qw(Exporter DynaLoader QPaintDevice);
 @EXPORT = qw(%ColorMode);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 bootstrap QPixmap $VERSION;
 
 1;
@@ -45,6 +45,7 @@ imageFormat,
 isOptimized,
 isQBitmap,
 load,
+loadFromData,
 isGloballyOptimized,
 isNull,
 optimize,
@@ -61,6 +62,9 @@ xForm
 
 Whatever has been interfaced is fully interfaced.
 
+The loadFromData function does not take a 'len' argument. All the other
+arguments are normal and in the original order.
+
 =head1 EXPORTED
 
 The C<%ColorMode> hash is exported into the user's namespace. The elements
