@@ -22,6 +22,11 @@ public:
 	QLabel(parent, name, f) {}
     PLabel(const char *text, QWidget *parent = 0, const char *name = 0,
 	   WFlags f = 0) : QLabel(text, parent, name, f) {}
+
+    QMetaObject *metaObject();
+    const char *className() const;
+protected:
+    void initMetaObject();
 };
 
 #endif  // PLABEL_H
